<style>
.md-content__inner > h1:nth-child(1) {
  display: none;
}
</style>

::: asockit.AsyncioReadableConnection
    options:
        show_bases: true

::: asockit.AsyncioWritableConnection
    options:
        show_bases: true

::: asockit.abc.ReadableConnection
    options:
        show_bases: true

::: asockit.abc.WritableConnection
    options:
        show_bases: true

::: asockit.abc.ConnectionClosedError
